@@ -13,19 +13,18 @@ import React from 'react'
 import resources from '../../../lib/shared/resources'
 import { PAGE_SIZES } from '../../actions/index'
 import {
-  PaginationV2, DataTable, OverflowMenu, OverflowMenuItem, Icon, Checkbox, TooltipIcon
+  PaginationV2, DataTable, OverflowMenu, OverflowMenuItem, Icon, Checkbox
 } from 'carbon-components-react'
+import { Tooltip } from '@patternfly/react-core'
 import PropTypes from 'prop-types'
 import { createDisableTooltip } from './DisableTooltip'
 import msgs from '../../../nls/platform.properties'
 import { transform } from '../../../lib/client/resource-helper'
 import { resourceActions } from './ResourceTableRowMenuItemActions'
 import { connect } from 'react-redux'
-import { getLink, getPrimaryKey, getSecondaryKey } from '../../definitions'
+import { getLink, getPrimaryKey, getSecondaryKey } from '../../tableDefinitions/index'
 import { Link, withRouter } from 'react-router-dom'
-import lodash from 'lodash'
-import ResourceTableRowExpandableContent from './ResourceTableRowExpandableContent'
-import ResourceTableRowExpandableList from './ResourceTableRowExpandableList'
+import _ from 'lodash'
 import filterUserAction from './FilterUserAction'
 import { LocaleContext } from './LocaleContext'
 import formatUserAccess from './FormatUserAccess'
@@ -46,14 +45,12 @@ const {
   TableRow,
   TableExpandHeader,
   TableBody,
-  TableExpandRow,
-  TableCell,
-  TableExpandedRow } = DataTable
+  TableCell
+} = DataTable
 
 export class ResourceTable extends React.Component {
   static contextType = LocaleContext
   render() {
-    const { locale } = this.context
     const {
       staticResourceData,
       page,
@@ -71,17 +68,13 @@ export class ResourceTable extends React.Component {
       itemIds,
       expandableTable,
       selectableTable,
-      tableExpandRowAriaLabel,
-      onSelect,
       onSelectAll,
-      onSelectSubItem,
-      listSubItems,
       placeHolderText,
       highLightRowName,
     } = this.props
 
-    const showSearch = lodash.get(this.props, 'showSearch', true)
-    const showPagination = lodash.get(this.props, 'showPagination', true)
+    const showSearch = _.get(this.props, 'showSearch', true)
+    const showPagination = _.get(this.props, 'showPagination', true)
     const id = (staticResourceData && staticResourceData.resourceKey)
       ? `${staticResourceData.resourceKey}-`
       : ''
@@ -117,7 +110,7 @@ export class ResourceTable extends React.Component {
         rows={this.getRows()}
         headers={this.getHeaders()}
         translateWithId={translateWithId.bind(null, this.context.locale)}
-        render={({ rows, headers, getRowProps }) => (
+        render={({ rows, headers }) => (
           <TableContainer id={`${id}table-container`}>
             {showSearch ?
               (<TableToolbar aria-label={`${id}search`} role='region'>
@@ -179,11 +172,11 @@ export class ResourceTable extends React.Component {
                             data-default-key={staticResourceData.defaultSortField}>
                             <span className='bx--table-header-label'>{header.header}</span>
                             { header.information &&
-                            <TooltipIcon align='end' tooltipText={header.information}>
+                            <Tooltip content={header.information}>
                               <svg className='info-icon'>
                                 <use href={'#diagramIcons_info'} ></use>
                               </svg>
-                            </TooltipIcon>
+                            </Tooltip>
                             }
                             <Icon
                               className='bx--table-sort-v2__icon'
@@ -205,103 +198,20 @@ export class ResourceTable extends React.Component {
               <TableBody>
                 {(() => {
                   return rows.map(row => {
-                    if (expandableTable && row && row.id) {//check undefined row.id to avoid whole page crush
+                    if(row && row.id){
                       return (
-                        <React.Fragment key={row.id}>
-                          <TableExpandRow
-                            {...getRowProps(
-                              { row,
-                                'data-row-name': lodash.get(items[row.id], lodash.get(staticResourceData, firstResKeyStr)),
-                                'aria-hidden': expandableTable && (
-                                  items[row.id] && !items[row.id].subItems || items[row.id] && items[row.id].subItems.length === 0
-                                ),
-                                className:
-                                  (lodash.get(items[row.id], lodash.get(staticResourceData, firstResKeyStr)) === highLightRowName)
-                                    ? 'high-light'
-                                    : expandableTable && (items[row.id] && !items[row.id].subItems || items[row.id] && items[row.id].subItems.length === 0)
-                                      ? 'row-not-expanded'
-                                      : ''
-                              })} ariaLabel={tableExpandRowAriaLabel ? tableExpandRowAriaLabel : 'TableExpandRow'
-                            }>
-                            {selectableTable &&
-                              <TableCell key={`select-checkbox-${row.id}`}>
-                                <Checkbox
-                                  checked={items[row.id] && !!items[row.id].selected}
-                                  indeterminate={
-                                    items[row.id] && items[row.id].subItems && items[row.id].subItems.length > 1
-                                    && items[row.id].subItems.filter(subItem => subItem.selected).length < items[row.id].subItems.length
-                                    && items[row.id].subItems.filter(subItem => subItem.selected).length !== 0}
-                                  id={row.id}
-                                  name={`select-checkbox-row-${row.id}`}
-                                  onChange={onSelect}
-                                  labelText={''}
-                                  aria-label={msgs.get(
-                                    items[row.id] &&
-                                    items[row.id].selected
-                                      ? 'unselect'
-                                      : 'select', this.context.locale
-                                  )}
-                                />
-                              </TableCell>
-                            }
-                            {row.cells.map(cell => {
-                              if (cell.id.split(':')[1] === 'metadata.name' && row.disabled) {
-                                return <TableCell key={cell.id} className='policy-table-name-ctr'>
-                                  <div className='policy-table-name-link'>{cell.value}</div>
-                                  <div className='disabled-label'>{msgs.get('policy.disabled.label', locale)}</div>
-                                </TableCell>
-                              }
-                              else {
-                                return <TableCell key={cell.id}>{cell.value}</TableCell>
-                              }
-                            })}
-                          </TableExpandRow>
-                          {row.isExpanded && listSubItems && (
-                            <TableExpandedRow>
-                              <TableCell colSpan={1} />
-                              <TableCell colSpan={8}>
-                                <ResourceTableRowExpandableList
-                                  items={items[row.id].subItems}
-                                  type='name' />
-                              </TableCell>
-                            </TableExpandedRow>
-                          )}
-                          {row.isExpanded && !listSubItems && (
-                            <TableExpandedRow>
-                              <TableCell colSpan={selectableTable ? 2 : 1} />
-                              <TableCell colSpan={1}>
-                                <ResourceTableRowExpandableContent
-                                  items={items[row.id].subItems}
-                                  type='name'
-                                  selectableTable={selectableTable}
-                                  onSelectSubItem={onSelectSubItem} />
-                              </TableCell>
-                              <TableCell colSpan={2}>
-                                <ResourceTableRowExpandableContent
-                                  type='type'
-                                  selectableTable={selectableTable}
-                                  items={items[row.id].subItems} />
-                              </TableCell>
-                            </TableExpandedRow>
-                          )}
-                        </React.Fragment>
+                        <TableRow
+                          key={row.id}
+                          data-row-name={_.get(items[row.id], _.get(staticResourceData, firstResKeyStr))}
+                          className={
+                            _.get(items[row.id], _.get(staticResourceData, firstResKeyStr)) === highLightRowName
+                              ? 'high-light'
+                              : ''
+                          }
+                        >
+                          {row.cells.map(cell => <TableCell key={cell.id}>{cell.value}</TableCell>)}
+                        </TableRow>
                       )
-                    } else {
-                      if(row && row.id){
-                        return (
-                          <TableRow
-                            key={row.id}
-                            data-row-name={lodash.get(items[row.id], lodash.get(staticResourceData, firstResKeyStr))}
-                            className={
-                              lodash.get(items[row.id], lodash.get(staticResourceData, firstResKeyStr)) === highLightRowName
-                                ? 'high-light'
-                                : ''
-                            }
-                          >
-                            {row.cells.map(cell => <TableCell key={cell.id}>{cell.value}</TableCell>)}
-                          </TableRow>
-                        )
-                      }
                     }
                     return undefined
                   })
@@ -330,21 +240,21 @@ export class ResourceTable extends React.Component {
       header: tableKey.dropdown ? '' : msgs.get(tableKey.msgKey, locale),
       information: tableKey.information ? msgs.get(tableKey.information, locale) : ''
     }))
-    tableActions && !lodash.isEmpty(tableActions) && headers.push({ key: 'action', header: ''})
+    tableActions && !_.isEmpty(tableActions) && headers.push({ key: 'action', header: ''})
     return headers
   }
 
   checkPolicyDisabled(data) {
-    return lodash.get(data, 'raw.spec.disabled', false)
+    return _.get(data, 'raw.spec.disabled', false)
   }
 
   checkPolicyRemediation(data) {
-    return lodash.get(data, 'raw.spec.remediationAction', 'inform')
+    return _.get(data, 'raw.spec.remediationAction', 'inform')
   }
 
   getRows() {
     const { history, items, itemIds, tableActions, resourceType, staticResourceData, match,
-      getResourceAction, userAccess, highLightRowName, autoAction, showSidePanel } = this.props
+      getResourceAction, userAccess } = this.props
     const { locale } = this.context
     const { normalizedKey } = staticResourceData
     const userAccessHash = formatUserAccess(userAccess)
@@ -352,32 +262,25 @@ export class ResourceTable extends React.Component {
       itemIds.map(
         id => items[id] || (Array.isArray(items)
         && items.find(target =>
-          (normalizedKey && lodash.get(target, normalizedKey) === id) || (target.name === id)
+          (normalizedKey && _.get(target, normalizedKey) === id) || (target.name === id)
         ))
       )
     if (localResources && localResources.length > 0) {
       return localResources.map((item, index) => {
         const row = {}
         if (normalizedKey) {
-          row.id = `${lodash.get(item, normalizedKey)}${lodash.get(item, 'cluster', '')}`
+          row.id = `${_.get(item, normalizedKey)}${_.get(item, 'cluster', '')}`
         } else {
           row.id = getSecondaryKey(resourceType)
-            ? `${lodash.get(item, getPrimaryKey(resourceType))}-${lodash.get(item, getSecondaryKey(resourceType))}`
-            : lodash.get(item, getPrimaryKey(resourceType)) || `table-row-${index}`
+            ? `${_.get(item, getPrimaryKey(resourceType))}-${_.get(item, getSecondaryKey(resourceType))}`
+            : _.get(item, getPrimaryKey(resourceType)) || `table-row-${index}`
         }
         const menuActions = item.metadata && item.metadata.namespace && tableActions
-                                && lodash.clone(tableActions[item.metadata.namespace]) || lodash.clone(tableActions)
+                                && _.clone(tableActions[item.metadata.namespace]) || _.clone(tableActions)
         const filteredActions = (Array.isArray(menuActions) && menuActions.length > 0)
           ? filterUserAction(item, menuActions, userAccessHash, resourceType)
           : []
 
-        //This is for grc policy page highlight item auto open side panel
-        if(showSidePanel && highLightRowName && autoAction
-          && (item.metadata && item.metadata.name && item.metadata.name === highLightRowName)
-          || (item.cluster && item.cluster === highLightRowName)){
-          getResourceAction(autoAction, item, null, history, locale)
-        }
-
         if (item.consoleURL && item.consoleURL === '-' && Array.isArray(filteredActions)){
           const removeIndex = filteredActions.indexOf('table.actions.launch.cluster')
           if (removeIndex > -1) {
@@ -419,7 +322,6 @@ export class ResourceTable extends React.Component {
                   isDelete={
                     action ==='table.actions.remove' ||
                     action ==='table.actions.policy.remove' ||
-                    action ==='table.actions.applications.remove' ||
                     action ==='table.actions.compliance.remove'
                   }
                   onClick={() => getResourceAction(action, item, null, history, locale)}
@@ -436,7 +338,7 @@ export class ResourceTable extends React.Component {
             <Link to={`${match.url}${getLink(key.link, item)}`}>{transform(item, key, locale)}</Link> :
             transform(item, key, locale)
           if (key.resourceKey === 'objectDefinition.metadata.name' && row[key.resourceKey] === '-') {
-            row[key.resourceKey] = lodash.get(item, 'objectDefinition.kind')
+            row[key.resourceKey] = _.get(item, 'objectDefinition.kind')
           }
           if (key.resourceKey === 'remediation') {
             row[key.resourceKey] = msgs.get('policy.remediation.' + row[key.resourceKey], locale)
@@ -468,59 +370,29 @@ export class ResourceTable extends React.Component {
 
 ResourceTable.propTypes = {
   actions: PropTypes.array,
-  addResource: PropTypes.func,
-  autoAction: PropTypes.string,
   changeTablePage: PropTypes.func,
-  children: PropTypes.oneOfType([PropTypes.object, PropTypes.array]),
-  clientSideFilters: PropTypes.string,
   darkSearchBox: PropTypes.bool,
-  deleteResource: PropTypes.func,
-  err: PropTypes.object,
   expandableTable: PropTypes.bool,
-  fetchResources: PropTypes.func,
   getResourceAction: PropTypes.func,
-  handleCreatePolicy: PropTypes.func,
   handleSearch: PropTypes.func,
   handleSort: PropTypes.func,
   highLightRowName: PropTypes.string,
   history: PropTypes.object.isRequired,
-  information: PropTypes.string,
   itemIds: PropTypes.array,
   items: PropTypes.object,
-  links: PropTypes.array,
-  listData: PropTypes.oneOfType([PropTypes.array, PropTypes.object]),
-  listSubItems: PropTypes.bool,
   match: PropTypes.object,
-  modifyResource: PropTypes.func,
-  mutateErrorMsg: PropTypes.string,
-  mutateStatus: PropTypes.string,
-  onSelect: PropTypes.func,
   onSelectAll: PropTypes.func,
-  onSelectSubItem: PropTypes.func,
-  onSelectedFilterChange: PropTypes.func,
   page: PropTypes.number,
   pageSize: PropTypes.number,
   placeHolderText: PropTypes.string,
-  resourceFilters: PropTypes.object,
   resourceType: PropTypes.object,
-  searchTable: PropTypes.func,
   searchValue: PropTypes.string,
   selectableTable: PropTypes.bool,
-  selectedFilters: PropTypes.object,
-  showSidePanel: PropTypes.bool,
   sortColumn: PropTypes.string,
   sortDirection: PropTypes.string,
-  sortTable: PropTypes.func,
   staticResourceData: PropTypes.object,
-  status: PropTypes.string,
   tableActions: PropTypes.array,
-  tableExpandRowAriaLabel: PropTypes.string,
-  tabs: PropTypes.array,
-  title: PropTypes.string,
-  topButton: PropTypes.oneOfType([PropTypes.array, PropTypes.object]),
   totalFilteredItems: PropTypes.number,
-  updateBrowserURL: PropTypes.func,
-  updateSecondaryHeader: PropTypes.func,
   userAccess: PropTypes.array,
 }
 
