@@ -6,14 +6,24 @@
  * Use, duplication or disclosure restricted by GSA ADP Schedule
  * Contract with IBM Corp.
  *******************************************************************************/
+/* Copyright (c) 2020 Red Hat, Inc. */
 'use strict'
 
 import React from 'react'
 import RefreshTimeSelect from '../../../../src-web/components/common/RefreshTimeSelect'
 import renderer from 'react-test-renderer'
 
+const refreshControl = {
+  reloading: false,
+  refreshCookie: 'grc-refresh-interval-cookie',
+  timestamp: 'Tue Sep 24 2019 16:07:17 GMT-0400 (Eastern Daylight Time)',
+  startPolling: jest.fn(),
+  stopPolling: jest.fn()
+}
+const refreshValues = [5,10,30,60,300,1800,0]
+
 describe('RefreshTimeSelect component', () => {
-  it('renders as expected', () => {
+  it('renders as expected without data', () => {
     const component = renderer.create(
       <RefreshTimeSelect
         locale = {'en-US'}
@@ -23,16 +33,29 @@ describe('RefreshTimeSelect component', () => {
     )
     expect(component.toJSON()).toMatchSnapshot()
   })
-})
-
-describe('RefreshTimeSelect component with data', () => {
-  it('renders as expected', () => {
-    const refreshControl = {
-      'reloading': false,
-      'refreshCookie': 'grc-refresh-interval-cookie',
-      'timestamp': 'Tue Sep 24 2019 16:07:17 GMT-0400 (Eastern Daylight Time)'
-    }
-    const refreshValues = [5,10,30,60,300,1800,0]
+  it('renders as expected with data', () => {
+    const component = renderer.create(
+      <RefreshTimeSelect
+        locale = {''}
+        refreshValues = {refreshValues}
+        refreshControl = {refreshControl}
+      />
+    )
+    expect(component.toJSON()).toMatchSnapshot()
+  })
+  it('renders as expected on change', () => {
+    const component = renderer.create(
+      <RefreshTimeSelect
+        locale = {''}
+        refreshValues = {refreshValues}
+        refreshControl = {refreshControl}
+      />
+    )
+    component.root.findByProps({className: 'selection'}).props.onChange({selectedItem: {pollInterval: 0}})
+    expect(component.toJSON()).toMatchSnapshot()
+  })
+  it('renders loading when reloading=true', () => {
+    refreshControl.reloading = true
     const component = renderer.create(
       <RefreshTimeSelect
         locale = {''}
