@@ -143,6 +143,7 @@ function (_Component) {
           isMobile = _this$props2.isMobile,
           other = _objectWithoutProperties(_this$props2, ["className", "disabled", "iconDescription", "id", "hideLabel", "label", "max", "min", "step", "invalid", "invalidText", "helperText", "light", "allowEmpty", "innerRef", "translateWithId", "isMobile"]);
 
+      var errorId = "".concat(id, "-error-id");
       var numberInputClasses = classNames("".concat(prefix, "--number ").concat(prefix, "--number--helpertext"), className, (_classNames = {}, _defineProperty(_classNames, "".concat(prefix, "--number--light"), light), _defineProperty(_classNames, "".concat(prefix, "--number--nolabel"), hideLabel), _defineProperty(_classNames, "".concat(prefix, "--number--mobile"), componentsX && isMobile), _classNames));
       var props = {
         disabled: disabled,
@@ -163,7 +164,8 @@ function (_Component) {
       if (invalid || !allowEmpty && this.state.value === '') {
         inputWrapperProps['data-invalid'] = true;
         error = React.createElement("div", {
-          className: "".concat(prefix, "--form-requirement")
+          className: "".concat(prefix, "--form-requirement"),
+          id: errorId
         }, invalidText);
       }
 
@@ -220,6 +222,9 @@ function (_Component) {
             type: "number",
             pattern: "[0-9]*"
           }, other, props, {
+            "data-invalid": invalid || null,
+            "aria-invalid": invalid || null,
+            "aria-describedby": errorId,
             ref: mergeRefs(ref, _this2._handleInputRef)
           })));
         }
