@@ -45,40 +45,25 @@ module.exports = class {
     this.uncaught(err);
   }
 
-  getCurrentPromise(err) {
+  async getCurrentPromise(err) {
     if (this.testRunner && this.testRunner.currentSuite) {
       this.testRunner.registerUncaughtErr(err);
       this.testRunner.currentSuite.emptyQueue();
 
-      return new Promise((resolve) => {
-        let runnable = this.testRunner.currentSuite.currentRunnable;
+      const {currentRunnable} = this.testRunner.currentSuite;
+      if (currentRunnable) {
+        await currentRunnable.abort(err);
+      }
 
-        if (runnable) {
-          runnable.abort(err).then(_ => resolve());
-        } else {
-          resolve();
-        }
-      }).then(_ => {
-        if (this.testRunner.publishReport) {
-          this.testRunner.publishReport = false;
+      await this.testRunner.closeOpenSessions();
 
-          return Promise.all([
-            this.testRunner.closeOpenSessions(),
-            this.testRunner.reportResults()
-          ]).catch(err => {
-            this.testRunner.registerUncaughtErr(err);
-
-            return err;
-          });
-        }
-
-        return Promise.resolve();
-      });
+      if (this.testRunner.publishReport) {
+        this.testRunner.publishReport = false;
+        await this.testRunner.reportResults();
+      }
     } else {
       Logger.error(err);
     }
-
-    return Promise.resolve();
   }
 
   uncaught(err) {
